@@ -3,7 +3,7 @@ pub use chrono::{DateTime, Datelike, Local, Timelike};
 pub use itertools::Itertools;
 pub use number_prefix::NumberPrefix;
 pub use rand::Rng;
-pub use rdkafka::{metadata::MetadataPartition, ClientConfig as KafkaConfig};
+pub use rdkafka::{error::KafkaError, metadata::MetadataPartition, ClientConfig as KafkaConfig};
 pub use std::{
     cmp,
     collections::{hash_map::Entry, BTreeMap, BTreeSet, HashMap, HashSet},
@@ -18,4 +18,9 @@ pub use std::{
 };
 pub use structopt::StructOpt;
 
-pub use crate::{colors::ColorAssignment, scrape, stats, stats::Stats, ui, Opts};
+pub use crate::{
+    colors::ColorAssignment,
+    scrape, stats,
+    stats::{Stats, Topic},
+    ui, Opts,
+};
